<?php
require_once(dirname(__FILE__) . '/../dashlet-helper.inc.php');

dashlets_data_check();

service_health_dashlet();

function service_health_dashlet() {

    $id = 'service_health_' . random_string(6);

    $categories = '';
    $ok = '';
    $warning = '';
    $critical = '';
    $unknown = '';
    $problems = '';
    $unhandled = '';

    $servers = get_servers();
    foreach ($servers as $server) {

        // We currently have nothing to show here for NLS, so don't show it
        if ($server['server_type'] == SERVER_TYPE_NLS) {
            continue;
        }

        $categories .= json_encode($server['name']) . ',';

        $data = get_server_data($server);
        if (!$data)
            continue;

        $ok .= $data['services_ok'] . ',';
        $warning .= $data['services_warning'] . ',';
        $critical .= $data['services_critical'] . ',';
        $unknown .= $data['services_unknown'] . ',';
        $problems .= $data['services_problems'] . ',';
        $unhandled .= $data['services_problems_unhandled'] . ',';
    }

    $categories = rtrim($categories, ',');
    $ok = rtrim($ok, ',');
    $warning = rtrim($warning, ',');
    $critical = rtrim($critical, ',');
    $unknown = rtrim($unknown, ',');
    $problems = rtrim($problems, ',');
    $unhandled = rtrim($unhandled, ',');

    ?>
        <div id="<?php echo $id; ?>" style="width: 100%; height: 100%">
        </div>
        <script type="text/javascript">
        $(function () {

            function get_<?php echo $id; ?>_content() {

                Highcharts.setOptions({
                    colors: [ '#b2ff5f', '#FEFF5F', '#FF795F', '#FFC45F', '#FFE4AF', '#ff4c00' ]
                });

                var chart = new Highcharts.Chart({
                    chart: {
                        renderTo: '<?php echo $id; ?>',
                        type: 'column',
                    },
                    credits: {
                        enabled: false
                    },
                    title: {
                        text: '<?php echo _('Service Health Summary by Nagios Server'); ?>'
                    },
                    xAxis: {
                        categories: [<?php echo $categories; ?>]
                    },
                    yAxis: {
                        allowDecimals: false,
                        min: 0,
                        
                        title: {
                            text: '<?php echo _('Counts by state'); ?>'
                        }
                    },
                    tooltip: {
                        formatter: function() {
                            return '<b>' + this.x + '</b><br/>'+
                                this.series.name +': '+ this.y +'<br/>'+
                                '<?php echo _('Total'); ?>: '+ this.point.stackTotal;
                        }
                    },
                    plotOptions: {
                        column: {
                            stacking: 'normal'
                        }
                    }, 
                    series: [
            			{
            	            name: '<?php echo _('Ok'); ?>',
            	            data: [<?php echo $ok; ?>],
            	            stack: 'state'
            	        },
            	        {
            	            name: '<?php echo _('Warning'); ?>',
            	            data: [<?php echo $warning; ?>],
            	            stack: 'state'
            	        },
            	        {
            	            name: '<?php echo _('Critical'); ?>',
            	            data: [<?php echo $critical; ?>],
            	            stack: 'state'
            	        },
                        {
                            name: '<?php echo _('Unknown'); ?>',
                            data: [<?php echo $unknown; ?>],
                            stack: 'state'
                        },
            	        {
            	            name: '<?php echo _('Problems'); ?>',
            	            data: [<?php echo $problems; ?>],
            	            stack: 'pseudo'
            	        },
            	        {
            	            name: '<?php echo _('Unhandled'); ?>',
            	            data: [<?php echo $unhandled; ?>],
            	            stack: 'pseudo'
            	        }
                    ]
                });
            }

            $('#<?php echo $id; ?>').closest('.ui-resizable').on('resizestop', function() {
                get_<?php echo $id; ?>_content();
            });

            get_<?php echo $id; ?>_content();
        }); 
        </script>
    <?php
}
