#!/bin/bash
 
#
# Sets up the fusion-sys.cfg file on install
#

SETVARDIR=$(dirname $(readlink -f $0))
setvar() {
    ${SETVARDIR}/set-fusion-var.sh "$1" "$2"
    eval "$1"=\"\$2\"
}

# Add a newline at end of file just in case there isn't one
printf "\n" >> fusion-sys.cfg

# Fusion version
setvar fusionver $(sed -n '/full/ s/.*=\(.*\)/\L\1/p' ./../fusion/var/fusionversion)

# OS-related variables have a detailed long variable, and a more useful short
# one: distro/dist, version/ver, architecture/arch. If in doubt, use the short
. ./get-os-info.sh
setvar distro  "$distro"
setvar version "$version"
setvar ver     "${version%%.*}" # short major version, e.g. "6" instead of "6.2"
setvar architecture "$architecture"

# Set dist variable like before (el5/el6 on both CentOS & Red Hat)
case "$distro" in
    CentOS | RedHatEnterpriseServer | oracleserver )
        setvar dist "el$ver"
        ;;
    Fedora )
        setvar dist "fedora$ver"
        ;;
    Debian )
        setvar dist "debian$ver"
        ;;
    "SUSE LINUX" )
        setvar dist "suse$ver"
        ;;
    *)
        setvar dist $(echo "$distro$ver" | tr A-Z a-z)
esac

# Architecture for el5
if [ "$dist $architecture" = "el5 i686" ]; then
    setvar arch i386
else
    setvar arch "$architecture"
fi

case "$dist" in
    el5 | el6 | el7 | fedora14 )
        if [ "$arch" = "x86_64" ]; then
            setvar php_extension_dir /usr/lib64/php/modules
        fi
        if [ "$dist" == "el7" ]; then
            setvar mysqld mariadb
        fi
        ;;
    suse11 | suse12 )
        if [ "$arch" = "x86_64" ]; then
            setvar php_extension_dir /usr/lib64/php5/extensions
            setvar apacheuser wwwrun
            setvar apachegroup www
            setvar httpdconfdir /etc/apache2/conf.d
            setvar httpdconf /etc/apache2/httpd.conf
            setvar httpdroot /srv/www/htdocs
            setvar phpini /etc/php5/cli/php.ini
            setvar phpconfd /etc/php5/conf.d
            setvar htpasswdbin /usr/bin/htpasswd2
            setvar httpd apache2
            setvar ntpd ntp
            setvar crond cron
            setvar mysqld mysql
        fi
        ;;
    ubuntu14 | ubuntu15 | ubuntu16 | debian7 | debian8 | debian9 )
            setvar apacheuser www-data
            setvar apachegroup www-data
            setvar httpdconf /etc/apache2/apache2.conf
            setvar httpdroot /var/www/html
            setvar phpini /etc/php5/apache2/php.ini
            setvar phpconfd /etc/php5/apache2/conf.d
            setvar phpconfdcli /etc/php5/cli/conf.d
            setvar httpd apache2
            setvar ntpd ntp
            setvar crond cron
            setvar mysqld mysql
        if [ "$dist" == "debian7" ]; then
            setvar httpdroot /var/www
            setvar php_extension_dir /usr/lib/php5/20100525
            setvar httpdconfdir /etc/apache2/conf.d
            setvar mibsdir /usr/share/mibs
            setvar php_cli_ini /etc/php5/cli/php.ini
        elif [ "$dist" == "debian8" ];then
            setvar php_extension_dir /usr/lib/php5/20131226
            setvar httpdconfdir /etc/apache2/conf-enabled
            setvar phpini /etc/php5/apache2/php.ini
            setvar php_cli_ini /etc/php5/cli/php.ini
        elif [ "$dist" == "debian9" ];then
            setvar php_extension_dir /usr/lib/php/20151012
            setvar php_cli_ini /etc/php/7.0/cli/php.ini
            setvar phpconfd /etc/php/7.0/apache2/conf.d
            setvar httpdconfdir /etc/apache2/conf-enabled
            setvar phpini /etc/php/7.0/apache2/php.ini
        elif [ "$dist" == "ubuntu14" ]; then
            setvar php_extension_dir /usr/lib/php5/20121212
            setvar phpini /etc/php5/apache2/php.ini
            setvar php_cli_ini /etc/php5/cli/php.ini
            setvar phpconfd /etc/php5/apache2/conf.d
            setvar httpdconfdir /etc/apache2/conf-enabled
            setvar mibsdir /usr/share/mibs
        elif [ "$dist" == "ubuntu16" ]; then
            setvar phpini /etc/php/7.0/apache2/php.ini
            setvar php_cli_ini /etc/php/7.0/cli/php.ini
            setvar phpconfd /etc/php/7.0/apache2/conf.d
            setvar php_extension_dir /usr/lib/php/20151012
            setvar httpdconfdir /etc/apache2/conf-enabled
            setvar mibsdir /usr/share/mibs
        else
            setvar php_extension_dir /usr/lib/php5/20121212
            setvar httpdconfdir /etc/apache2/conf-enabled
        fi
            
        ;;
    *)
        :
esac

# Make sure we are using the exact php extension dir
if [ `command -v php-config` ]; then
    php_extension_dir=$(php-config --extension-dir)
fi
